@@ -21,14 +21,14 @@ MINOR_HARMONY = {
     'ü': 'ü'
 }
 
-MINOR_HARMONY_FOR_FUTURE = {
+HARMONY_FOR_PRESENT_FIRST = {
     'a': 'a',
     'e': 'e',
-    'ö': 'ü',
-    'o': 'u',
-    'ı': 'ı',
+    'ö': 'e',
+    'o': 'a',
+    'ı': 'a',
     'i': 'e',
-    'u': 'u',
+    'u': 'a',
     'ü': 'e'
 }
 
